import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashSet;

import jec.EventSearchCriteria;
import jec.ExchangeConnectorFactory;
import jec.ExchangeConnectorInterface;
import jec.ExchangeConstants;
import jec.ExchangeGeneralException;
import jec.InvalidSearchCriteriaException;
import jec.OREventSearchCriteria;
import jec.dto.ExchangeContactDTO;
import jec.dto.ExchangeEmailDTO;
import jec.dto.ExchangeEventAttendeeDTO;
import jec.dto.ExchangeEventDTO;
import jec.dto.ExchangeTaskDTO;
import jec.dto.FolderDTO;
import jec.dto.UserAvailabilityData;
import jec.utils.AppLogger;
import java.util.Calendar;


public class ExchangeConnectorExamples {

    static  String _exchangeHost = "192.168.0.102";
    static  String _applicationUserAccountName = "test1";
    static  String _applicationUserPassword = "Kikaha58";
    static  String _prefix = "Exchange";
    static  String _mailboxName = "test1";
    //static String _domain = "domain1.com";
    static  boolean _useSSL = true;
    static String _email = "test1@domain1.com";



    static String _contactUniqueIdForURL = null;
    static String _eventUniqueIdForURL = null;
    static String _taskUniqueIdForURL = null;
    static String _emailUniqueIdForUrl = null;


    public static void main(String[] args) {
        try {
            BufferedReader in = new BufferedReader(new InputStreamReader(System.
                    in));
            String str = null;
            System.out.println("Welcome to JEC example!");
            System.out.println(
                    "To use the main default values just press <Enter>");
            System.out.println("");
            System.out.println("Please insert Exchange IP or host name: ");
            try {
                str = in.readLine();
            } catch (IOException ex1) {
                ex1.printStackTrace();
            }
            if ((str != null) && (!str.equals("")))
                _exchangeHost = str;
            System.out.println("Exchange Host:" + _exchangeHost);
            System.out.println("");

            System.out.println("Please insert Exchange user name: ");
            try {
                str = in.readLine();
            } catch (IOException ex1) {
                ex1.printStackTrace();
            }
            if ((str != null) && (!str.equals("")))
                _applicationUserAccountName = str;
            System.out.println("");
            System.out.println("Application User Account Name:" +
                               _applicationUserAccountName);

            System.out.print("Please insert Exchange password: ");
            try {
                str = in.readLine();
            } catch (IOException ex1) {
                ex1.printStackTrace();
            }
            if ((str != null) && (!str.equals("")))
                _applicationUserPassword = str;
            System.out.println("");
            System.out.println("Application User Password:" +
                               _applicationUserPassword);

            System.out.print(
                    "Please insert mailbox name (in most cases its the same as the user name): ");
            try {
                str = in.readLine();
            } catch (IOException ex1) {
                ex1.printStackTrace();
            }
            if ((str != null) && (!str.equals("")))
                _mailboxName = str;
            System.out.println("");
            System.out.println("Mailbox Name:" + _mailboxName);

// ============== basic tests ==========================
            getContactsExample();
            addContactExample();
            updateContactExample();
            deleteContactExample();
            getPublicContactsExample();
//
            addEventExample();
            addEventWithAttendeesExample();
            authenticateExample();
            updateEventExample();
            getEventsExample();
            deleteEventExample();
            getEventsFilteredExample();
            getUserAvalabilityExample();
            // need javamail lib
            //sendMeetingRequestExample();

            getEmailsExample();
            getEmailsSentItemsExample();
            createEmailInDraftsFolderExample();
            deleteEmailFromDraftsFolderExample();
            sendEmailExample();

            getTasksExample();
            addTaskExample();
            updateTaskExample();
            deleteTaskExample();

            getFoldersExample();

// ============== advanced tests ==========================
// make sure you have permissions to do this operations.
//          addPublicContactExample();
//          updatePublicContactExample();
//          getEventsFromNestedEventFolderExample();
//          getEventsFromI18NEventFolderExample();
//          getEmailsWithFBAExample();
//          deleteEmailUsingIdExample();
//          sendEmailThatExistsInExchangeExample();
//          acceptMeetingExample();
//
// ============== other tests ==========================
//            addEventExample2();
//            addEventTimezoneExample();
//            deleteEventExample2();
//            getEventsORFilteredExample();
//            updateTaskFullExample();
//            deleteFirstEventExample();

//            addEventAllDayExample();
//            getEventsExample2();
//            getEventByIDExample();
//            getEventAndUpdateIt();
//            createConnectorWithExplicitLicenseFileLocationExample();
//            getContactsSubFloderExample();
//            addContactSubFolderExample();
//            searchAndDeleteEmailExample();
//              getEmailsFromPublicFolderExample();



        } catch (ExchangeGeneralException ex) {
            ex.printStackTrace();
        }
    }

    public static void addContactExample() throws ExchangeGeneralException {

        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

        ExchangeContactDTO contact = new ExchangeContactDTO();
        contact.setFirstName("guy3");
        contact.setLastName("jeno3");
        contact.setEmail("bushi@tech.com");
        _contactUniqueIdForURL = "" + System.currentTimeMillis();
        contact.setUniqueIdForUrl(_contactUniqueIdForURL);
        System.out.println("Adding contact: " + _contactUniqueIdForURL);
        connector.addContact(contact);
        System.out.println(
                "look at the contact list to see that the contact is added.");
    }


    public static void updateContactExample() throws ExchangeGeneralException {

        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

        ArrayList contacts = connector.getContacts();

        for (int i = 0; i < contacts.size(); i++) {
            ExchangeContactDTO contact = (ExchangeContactDTO) contacts.get(i);

            String emailAddr = contact.getEmail();
            if (emailAddr.equals("bushi@tech.com")) {
                contact.setFirstName(contact.getFirstName() + " *changed*");
                connector.updateContact(contact);
            }
        }
        System.out.println(
                "look at the contact list to see that the contact was updated.");

    }

    public static void deleteContactExample() throws ExchangeGeneralException {
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

        try {
            System.out.println("Deleting Contact: " + _contactUniqueIdForURL);
            connector.deleteContact(_contactUniqueIdForURL);
        }

        catch (ExchangeGeneralException ex) {
            ex.printStackTrace();
        }
    }


    public static void getContactsExample() throws ExchangeGeneralException {
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

//        connector.setUseFba(true);
//        connector.setDomain(_domain);

        // If you want to avoid adding the below to the command line
        //-Djavax.net.ssl.trustStore=.\lib\privkeystore
        // you can use this system call
        //System.setProperty("javax.net.ssl.trustStore", "lib\\privkeystore");


        ArrayList contacts = connector.getContacts();

        for (int i = 0; i < contacts.size(); i++) {
            ExchangeContactDTO contact = (ExchangeContactDTO) contacts.get(i);
            System.out.println("contact.getUniqueIdForUrl(): " +
                               contact.getUniqueIdForUrl());
            System.out.println("contact.getExchangeId(): " +
                               contact.getExchangeId());
            System.out.println("contact.getFirstName(): " +
                               contact.getFirstName());
            System.out.println("contact.getLastName(): " + contact.getLastName());
            System.out.println("contact.getMiddleName(): " + contact.getMiddleName());
            System.out.println("");


        }
    }


    public static void addEventExample() throws ExchangeGeneralException {

        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

        SimpleDateFormat dateFormat = new SimpleDateFormat(
                "yyyy-MM-dd HH:mm:ss");
        Date startDate = null;
        Date endDate = null;
        try {
            startDate = dateFormat.parse("2007-10-25 11:00:00");
            endDate = dateFormat.parse("2007-10-25 12:00:00");
        } catch (ParseException ex) {
            ex.printStackTrace();
        }

        ExchangeEventDTO event = new ExchangeEventDTO();

        _eventUniqueIdForURL = "" + System.currentTimeMillis();
        event.setUniqueIdForUrl(_eventUniqueIdForURL);

        event.setSubject("<eli test event");
        event.setDescription("my test event");
        event.setStartDate(startDate);
        event.setEndDate(endDate);
        event.setImportance(2);
        event.setLocation("<test> location");

        //event.setIsAllDayEvent(true);
        //event.setId(_eventUniqueIdForURL);

        connector.addEvent(event);
        System.out.println("look at: " + startDate +
                           " events to see that the event was added.");
    }


    public static void addEventTimezoneExample() throws
            ExchangeGeneralException {

        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName, "GMT+03:00");

        Date startDate = new Date();
        Date endDate = new Date();

        ExchangeEventDTO event = new ExchangeEventDTO();

        _eventUniqueIdForURL = "" + System.currentTimeMillis();
        event.setUniqueIdForUrl(_eventUniqueIdForURL);

        event.setSubject("eli test event");
        event.setDescription("my test event");
        event.setStartDate(startDate);
        event.setEndDate(endDate);
        event.setId(_eventUniqueIdForURL);

        connector.addEvent(event);
        System.out.println(
                "look at the todays events to see that the event was added.");
    }

    public static void addEventAllDayExample() throws ExchangeGeneralException {
        System.out.println(
                "============ addEventAllDayExample start =============");
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName /*, "GMT+03:00"*/);
//        connector.setAllDayEventTimeShifter("GMT+03:00");
        connector.setAllDayEventTimeShifter("GMT+02:00");



        Date startDate = new Date();
        Date endDate = new Date();
//        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
//        try {
//            startDate = dateFormat.parse("2007-04-26 17:00:00");
//            endDate = dateFormat.parse("2007-04-26 18:00:00");
//        } catch (ParseException ex) {
//            ex.printStackTrace();
//        }


        ExchangeEventDTO event = new ExchangeEventDTO();

        _eventUniqueIdForURL = "" + System.currentTimeMillis();
        event.setUniqueIdForUrl(_eventUniqueIdForURL);

        event.setSubject("test all day event");
        event.setDescription("my allday test event");
        event.setStartDate(startDate);
        event.setEndDate(endDate);
        event.setIsAllDayEvent(true);
        event.setId(_eventUniqueIdForURL);

        connector.addEvent(event);
        System.out.println(
                "look at the todays events to see that the event was added.");
        System.out.println(
                "============ addEventAllDayExample end =============");
    }


    public static void updateEventExample() throws ExchangeGeneralException {

        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

        ExchangeEventDTO exEvent = new ExchangeEventDTO();

        // the id is taken from the original event created at the testAddEvent
        exEvent.setUniqueIdForUrl(_eventUniqueIdForURL);

        exEvent.setDescription("my event2");

        // both fields are must
//        exEvent.setStartDate(new Date());
//        exEvent.setEndDate(new Date());

        // updating only the subject
        exEvent.setSubject("eli test2 updated");

        System.out.println("updating event: " + exEvent);
        connector.updateEvent(exEvent);
    }

    public static void deleteEventExample() throws ExchangeGeneralException {
        System.out.println("============= delete event example start. =========================");
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);
        // this is the default
        //connector.setDeletedFolderName("Deleted%20Items");

        try {
            connector.deleteEvent(_eventUniqueIdForURL);
            System.out.println("event (eventUniqueId): " + _eventUniqueIdForURL + " deleted.");
        } catch (ExchangeGeneralException ex) {
            ex.printStackTrace();
        }
        System.out.println("============= delete event example end. =========================");

    }


    public static void deleteEventExample2() throws ExchangeGeneralException {
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

        //String eventFileName = eventUniqueId;

        SimpleDateFormat dateFormat = new SimpleDateFormat(
                "yyyy-MM-dd HH:mm:ss");
        Date startDate = null;
        Date endDate = null;
        try {
//            startDate = dateFormat.parse("2006-09-24 21:00:00");
//            endDate = dateFormat.parse("2006-10-18 21:00:00");

            startDate = dateFormat.parse("2006-12-5 21:00:00");
            endDate = dateFormat.parse("2006-12-7 21:00:00");
        } catch (ParseException ex) {
            ex.printStackTrace();
        }
        System.out.println("getting events from startDate: " + startDate +
                           " to endDate: " + endDate);

        ArrayList events = connector.getEvents(startDate,
                                               endDate, 5);
        for (int i = 0; i < events.size(); i++) {
            System.out.println("event " + i + " subject: " +
                               ((ExchangeEventDTO) events.get(i)).getSubject());
            System.out.println("event " + i + " location: " +
                               ((ExchangeEventDTO) events.get(i)).getLocation());
            AppLogger.getLogger().debug("event " + i + " location: " +
                                        ((ExchangeEventDTO) events.get(i)).
                                        getLocation());
            try {
                if (i == 0) {
                    System.out.println("trying to delete event: " +
                                       ((ExchangeEventDTO) events.get(i)).
                                       getUniqueIdForUrl());
                    connector.deleteEvent(((ExchangeEventDTO) events.get(i)).
                                          getUniqueIdForUrl());
                }
            } catch (ExchangeGeneralException ex) {
                ex.printStackTrace();
            }

        }


    }


    public static void getEventsFilteredExample() throws
            ExchangeGeneralException {
        System.out.println("====== getEventsFilteredExample start ==========");
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

        SimpleDateFormat dateFormat = new SimpleDateFormat(
                "yyyy-MM-dd HH:mm:ss");
        Date startDate = null;
        Date endDate = null;
        try {
            startDate = dateFormat.parse("2006-11-24 08:00:00");
//            startDate = dateFormat.parse("2006-11-28 06:00:00");
            endDate = dateFormat.parse("2006-11-29 21:00:00");
        } catch (ParseException ex) {
            ex.printStackTrace();
        }
        System.out.println("getting events from startDate: " + startDate +
                           " to endDate: " + endDate);
        try {

            // get only all day events
//            EventSearchCriteria eventSearchCriteria = new EventSearchCriteria(
//                    ".*", ".*", ".*", -1, 1);

            // get only recurrent events
//            EventSearchCriteria eventSearchCriteria = new EventSearchCriteria(
//                    ".*", ".*", ".*", 1, -1);

            // get only not recurrent events
//            EventSearchCriteria eventSearchCriteria = new EventSearchCriteria(
//                    ".*", ".*", ".*", 0, -1);

            // get all events that their subject start with "w"
//            EventSearchCriteria eventSearchCriteria = new EventSearchCriteria(
//                    "w.*", ".*", ".*", -1, -1);

            // get all events that their subject start with "w" and that are recurrent
//            EventSearchCriteria eventSearchCriteria = new EventSearchCriteria(
//                    "w.*", ".*", ".*", -1, -1);

            // get all events that their subject contains the word "the"
//            EventSearchCriteria eventSearchCriteria = new EventSearchCriteria(
//                    ".*the.*", ".*", ".*", -1, -1);

            // get all events that their subject contains the word "the" no case sensitive
            EventSearchCriteria eventSearchCriteria = new EventSearchCriteria(
                    ".*[tT][Hh][Ee].*", ".*", ".*", -1, -1);

            ArrayList events = connector.getEvents(startDate, endDate,
                    eventSearchCriteria);
//            ArrayList events = connector.getEvents(startDate, endDate,
//                    50);
            for (int i = 0; i < events.size(); i++) {
                System.out.println("event " + i + " subject: " +
                                   ((ExchangeEventDTO) events.get(i)).
                                   getSubject());
                System.out.println("event " + i + " location: " +
                                   ((ExchangeEventDTO) events.get(i)).
                                   getLocation());
                System.out.println("event " + i + " StartDate: " +
                                   ((ExchangeEventDTO) events.get(i)).
                                   getStartDate()
                        );
                System.out.println("event " + i + " EndDate: " +
                                   ((ExchangeEventDTO) events.get(i)).
                                   getEndDate()
                        );
                System.out.println("event " + i + " exchange id: " +
                                   ((ExchangeEventDTO) events.get(i)).
                                   getUniqueIdForUrl());
                System.out.println("event " + i + " description: " +
                                   ((ExchangeEventDTO) events.get(i)).
                                   getDescription());

            }
            System.out.println("====== getEventsFilteredExample end ==========");
        } catch (InvalidSearchCriteriaException e) {
            e.printStackTrace();
        }

    }

    public static void getEventsExample() throws ExchangeGeneralException {

        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;


        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName, "GMT+02:00");


        Date startDate = null;
        Date endDate = null;
        try {
            // getting todays events (6:00 -> 22:00)
            Date today = new Date();
            Calendar calStart = Calendar.getInstance();
            Calendar calEnd = Calendar.getInstance();
            calStart.setTime(today);
            calStart.set(Calendar.HOUR_OF_DAY, 6);
            calStart.set(Calendar.MINUTE, 0);

            calEnd.setTime(today);
            calEnd.set(Calendar.HOUR_OF_DAY, 22);
            calEnd.set(Calendar.MINUTE, 0);
            startDate = calStart.getTime();
            endDate = calEnd.getTime();
        } catch (Exception ex) {
            ex.printStackTrace();
        }
        System.out.println("getting events from startDate: " + startDate +
                           " to endDate: " + endDate);

        ArrayList events = connector.getEvents(startDate,
                                               endDate, 100);
        for (int i = 0; i < events.size(); i++) {
            System.out.println("event " + i + " getUniqueIdForUrl: " +
                               ((ExchangeEventDTO) events.get(i)).getUniqueIdForUrl());
            System.out.println("event " + i + " subject: " +
                               ((ExchangeEventDTO) events.get(i)).getSubject());
            System.out.println("event " + i + " location: " +
                               ((ExchangeEventDTO) events.get(i)).getLocation());
            System.out.println("event " + i + " busy status: " +
                               ((ExchangeEventDTO) events.get(i)).getBusyStatus());
            System.out.println("event " + i + " all day event: " +
                               ((ExchangeEventDTO) events.get(i)).
                               getIsAllDayEvent());
            System.out.println("event " + i + " StartDate: " +
                              ((ExchangeEventDTO) events.get(i)).getStartDate()
                              );

            System.out.println("event " + i + " EndDate: " +
                              ((ExchangeEventDTO) events.get(i)).getEndDate()
                              );


            System.out.println("event " + i + " Is Recurrent event: " +
                               ((ExchangeEventDTO) events.get(i)).
                               getIsRecurrent());

            ////////////////////////////// getting event attendees ///////////////////////////
            if ( ((ExchangeEventDTO) events.get(i)).getTo()!= null) {
                System.out.println("event " + i + " number of attendees: " +
                                   ((ExchangeEventDTO) events.get(i)).getTo().
                                   size());
                for (int j = 0; j < ((ExchangeEventDTO) events.get(i)).getTo().
                                   size(); j++) {
                    System.out.println("attendee " + j + ":" +
                            ((ExchangeEventAttendeeDTO)(((ExchangeEventDTO) events.get(i)).getTo().get(j))).getDisplayName() +
                             " " +
                            ((ExchangeEventAttendeeDTO)(((ExchangeEventDTO) events.get(i)).getTo().get(j))).getEmailAddr()   );

                    System.out.println("attendee " + j + " type (ATTENDEE_TYPE_REQUIRED=1, ATTENDEE_TYPE_=3)" + j + ":" +
                                       ((ExchangeEventAttendeeDTO) (((
                            ExchangeEventDTO) events.get(i)).getTo().get(j))).getType()
                                       );
                    System.out.println("attendee " + j + ":" +
                            ((ExchangeEventAttendeeDTO)(((ExchangeEventDTO) events.get(i)).getTo().get(j))).getDisplayNameAndEmailStr());

                }
            }
            ////////////////////////////////////////////////////////////////////////////////////////////////

            System.out.println("");

        }

    }

    public static void getEventsExample2() throws ExchangeGeneralException {

        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName, "GMT+00:00");

        SimpleDateFormat dateFormat = new SimpleDateFormat(
                "yyyy-MM-dd HH:mm:ss");
        Date startDate = null;
        Date endDate = null;
        try {
            startDate = dateFormat.parse("2007-09-06 06:00:00");
            endDate = dateFormat.parse("2007-09-06 21:00:00");
        } catch (ParseException ex) {
            ex.printStackTrace();
        }
        System.out.println("getting events from startDate: " + startDate +
                           " to endDate: " + endDate);

        ArrayList events = connector.getEvents(startDate,
                                               endDate, 5);
        for (int i = 0; i < events.size(); i++) {
            System.out.println("event " + i + " subject: " +
                               ((ExchangeEventDTO) events.get(i)).getSubject());
            System.out.println("event " + i + " location: " +
                               ((ExchangeEventDTO) events.get(i)).getLocation());
            System.out.println("event " + i + " StartDate: " +
                               ((ExchangeEventDTO) events.get(i)).getStartDate());
            System.out.println("event " + i + " EndDate: " +
                               ((ExchangeEventDTO) events.get(i)).getEndDate());
            System.out.println("event " + i + " isAllDay: " +
                               ((ExchangeEventDTO) events.get(i)).
                               getIsAllDayEvent());
            System.out.println("event " + i + " priority: " +
                    ((ExchangeEventDTO) events.get(i)).
                    getPriority());
            System.out.println("event " + i + " getUniqueIdForUrl: " +
                    ((ExchangeEventDTO) events.get(i)).
                    getUniqueIdForUrl());
            System.out.println("event " + i +
                               " importance (0-> low, 1-> normal, 2->high): " +
                               ((ExchangeEventDTO) events.get(i)).getImportance());
        }

    }

    public static void authenticateExample() throws ExchangeGeneralException {

        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        //        connector = factory.createExchangeConnector(_exchangeHost ,
        //                "foo",
        //               _applicationUserPassword   /*"1234"*/,
        //                _prefix, _mailboxName );

        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

        connector.authenticate();
        System.out.println("authenticated.");
    }

    public static void getEmailsExample() throws ExchangeGeneralException {
        System.out.println("============== getEmailsExample() start ===========");
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;

        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

        SimpleDateFormat dateFormat = new SimpleDateFormat(
                "yyyy-MM-dd HH:mm:ss");
        Date sinceDate = null;
        try {
            sinceDate = dateFormat.parse("2007-10-03 17:00:00");
        } catch (ParseException ex) {
            ex.printStackTrace();
        }
        HashSet fromEmailAddressFilter = null;

        // uncomment to enable from filter
        //fromEmailAddressFilter = new HashSet();
        //fromEmailAddressFilter.add("test@domain1.com");

        HashSet toEmailAddressFilter = null;
        int maxEmailsReturned = 10;

        // in-order to get only un-read emails uncomment the below line
        //connector.setGetOnlyUnreadEmails(true);

        ArrayList emailsArrayList = connector.getEmails(
                sinceDate,
                fromEmailAddressFilter,
                toEmailAddressFilter,
                maxEmailsReturned);
        System.out.println("emailsArrayList.size() : " + emailsArrayList.size());
       for (int i = 0; i <  emailsArrayList.size(); i++) {
            ExchangeEmailDTO email = (ExchangeEmailDTO) emailsArrayList.get(i);
            System.out.println("email1.getUniqueIdForUrl(): " +
                               email.getUniqueIdForUrl());
            System.out.println("email1.getSubject(): " +
                               email.getSubject());
//            System.out.println("email1.getBody(): " +
//                               email.getBody());
            System.out.println("email1.getDateReceived(): " +
                               email.getDateReceived());
            System.out.println("email1.getTo(): " +
                               email.getTo());
            System.out.println("email1.getFrom(): " +
                               email.getFrom());
            System.out.println("email1.isRead: " +
                               email.isRead());
            System.out.println("email1.getCc: " +
                               email.getCc());
            System.out.println("email1.getBcc: " +
                               email.getBcc());
            System.out.println("");


        }
        System.out.println("============== getEmailsExample() end ============");
    }

    public static void getEmailsSentItemsExample() throws
            ExchangeGeneralException {

        System.out.println("============= getEmailsSentItemsExample start ================");
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;

        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

        connector.setEmailFolderName("Sent%20Items");

        SimpleDateFormat dateFormat = new SimpleDateFormat(
                "yyyy-MM-dd HH:mm:ss");
        Date sinceDate = null;
        try {
            sinceDate = dateFormat.parse("2007-01-25 06:00:00");
        } catch (ParseException ex) {
            ex.printStackTrace();
        }
        HashSet fromEmailAddressFilter = null;
//        fromEmailAddressFilter = new HashSet();
//        fromEmailAddressFilter.add("ehasson@domain.com");
        HashSet toEmailAddressFilter = null;
        int maxEmailsReturned = 10;
        ArrayList emailsArrayList = connector.getEmails(
                sinceDate,
                fromEmailAddressFilter,
                toEmailAddressFilter,
                maxEmailsReturned);
        System.out.println("emailsArrayList.size() : " + emailsArrayList.size());
        if (emailsArrayList.size() > 0) {
            for (int i=0; i < emailsArrayList.size(); i++ ) {
                ExchangeEmailDTO email1 = (ExchangeEmailDTO) emailsArrayList.
                                          get(i);
                System.out.println("email1 email1.getSubject(): " +
                                   email1.getSubject());
//            System.out.println("email1.getBody(): " +
//                               email1.getBody());
                System.out.println("email1.getDateReceived(): " +
                                   email1.getDateReceived());
                System.out.println("email1.getTo(): " +
                                   email1.getTo());
                System.out.println("email1.getFrom(): " +
                                   email1.getFrom());
                System.out.println("email1.isRead: " +
                                   email1.isRead());
                System.out.println("email1.getCc: " +
                                   email1.getCc());
                System.out.println("email1.getBcc: " +
                                   email1.getBcc());

                System.out.println("");
            }
            System.out.println("============= getEmailsSentItemsExample end ================");


        }
    }


    public static void getTasksExample() throws ExchangeGeneralException {
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName, "GMT+02:00");

        ArrayList tasks = connector.getTasks();
        if (tasks.size() > 0) {
            int j = (tasks.size() < 10) ? tasks.size() : 10;
            for (int i = 0; i < j; i++) {
                ExchangeTaskDTO task = (ExchangeTaskDTO) tasks.get(i);
                System.out.println("============ task " + i +
                                   " start =============================");
                System.out.println("task.subject(): " + task.getSubject());
                System.out.println("task.isComplete(): " + task.isCompleted());
                System.out.println("task.getDueDate(): " + task.getDueDate());
                System.out.println("task.getPercentComplete(): " +
                                   task.getPercentComplete());
                System.out.println("task.getPriority(): " + task.getPriority());
                System.out.println("task.getFrom(): " + task.getFrom());
                System.out.println("task.getCreationDate(): " +
                                   task.getCreationDate());
                System.out.println("task.getLastModifiedDate(): " +
                                   task.getLastModifiedDate());
                System.out.println("task.getStatus(): " + task.getStatus());
                //System.out.println("task.getTextDescription(): " + task.getTextDescription());
                System.out.println("task.getUniqueIdForUrl(): " +
                                   task.getUniqueIdForUrl());
                System.out.println("============ task " + i +
                                   " end =============================");
            }
        } else {
            System.out.println("you dont have tasks.");
        }
    }


    public static void addTaskExample() throws ExchangeGeneralException {
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName,
                "GMT+02:00");
        ExchangeTaskDTO task = new ExchangeTaskDTO();
        task.setSubject("test task2");
        task.setTextDescription("test desc2");
        // not updated in the exchange ui
        task.setPriority("0");
        task.setIsCompleted(true);
        // a number between 0-1 for example: 0.75
        task.setPercentComplete("0");
        // this field acually complete the task
        task.setStatus(ExchangeConstants.TASK_STATUS_NOT_STARTED);
        SimpleDateFormat dateFormat = new SimpleDateFormat(
                "yyyy-MM-dd HH:mm:ss");

        Date dueDate = null;
        try {
            dueDate = dateFormat.parse("2007-03-23 18:00:00");

        } catch (ParseException ex) {
            ex.printStackTrace();
        }
        // not updated in the exchange ui
        task.setDueDate(dueDate);

        Date startDate = null;
        try {
            startDate = dateFormat.parse("2007-03-22 13:00:00");

        } catch (ParseException ex) {
            ex.printStackTrace();
        }
        // not updated in the exchange ui
        task.setStartDate(startDate);

        connector.addTask(task);
        _taskUniqueIdForURL = task.getUniqueIdForUrl();
        System.out.println("task: " + _taskUniqueIdForURL + " created.");

    }

    public static void updateTaskFullExample() throws ExchangeGeneralException {
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName, "GMT+02:00");

        ArrayList tasks = connector.getTasks();
        if (tasks.size() > 0) {

            ExchangeTaskDTO task = (ExchangeTaskDTO) tasks.get(0);
            System.out.println("task.subject(): " + task.getSubject());
            System.out.println("task.isComplete(): " + task.isCompleted());
            System.out.println("task.getDueDate(): " + task.getDueDate());
            System.out.println("task.getStartDate(): " + task.getStartDate());
            System.out.println("task.getPercentComplete(): " +
                               task.getPercentComplete());
            System.out.println("task.getPriority(): " + task.getPriority());
            System.out.println("task.getStatus(): " + task.getStatus());
            System.out.println("task.getUniqueIdForUrl(): " +
                               task.getUniqueIdForUrl());

            task.setSubject(task.getSubject() + " u");
            task.setTextDescription("bla bla");
            task.setPriority("2");
            task.setIsCompleted(true);
            // a number between 0-1 for example: 0.75
            task.setPercentComplete("1");
            // this field acually complete the task
            task.setStatus(ExchangeConstants.TASK_STATUS_COMPLETED);

            SimpleDateFormat dateFormat = new SimpleDateFormat(
                    "yyyy-MM-dd HH:mm:ss");

            Date dueDate = null;
            try {
                dueDate = dateFormat.parse("2007-01-16 18:00:00");

            } catch (ParseException ex) {
                ex.printStackTrace();
            }
            task.setDueDate(dueDate);

            Date startDate = null;
            try {
                startDate = dateFormat.parse("2007-01-13 13:00:00");

            } catch (ParseException ex) {
                ex.printStackTrace();
            }
            task.setStartDate(startDate);

            connector.updateTask(task);
            System.out.println("task: " + task.getUniqueIdForUrl() +
                               " updated.");

        } else {
            System.out.println("you dont have tasks.");
        }
    }

    public static void updateTaskExample() throws
            ExchangeGeneralException {
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

        ExchangeTaskDTO task = new ExchangeTaskDTO();
        task.setUniqueIdForUrl(_taskUniqueIdForURL);
        task.setSubject("subject updated");
        //task.setTextDescription("desc updated");
        task.setStatus(ExchangeConstants.TASK_STATUS_COMPLETED);

        connector.updateTask(task);
        System.out.println("task: " + task.getUniqueIdForUrl() + " updated.");

    }


    public static void getPublicContactsExample() throws
            ExchangeGeneralException {
        System.out.println(
                "========================= getPublicContactsExample ===================");
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

        // you should use this method only if the Public Contacts folder name
        //is diffrent then the default (Public Contacts)
        //connector.setPublicContactsFolderName("contacts2");

        ArrayList contacts = connector.getPublicContacts();

        for (int i = 0; i < contacts.size(); i++) {
            ExchangeContactDTO contact = (ExchangeContactDTO) contacts.get(i);
            System.out.println();
            System.out.println("contact.getUniqueIdForUrl(): " +
                               contact.getUniqueIdForUrl());
            System.out.println("contact.getFirstName(): " +
                               contact.getFirstName());
            System.out.println("contact.getFirstName(): " +
                               contact.getLastName());
            System.out.println("contact.getEmail() " +
                               contact.getEmail());

        }
    }

    public static void addPublicContactExample() throws
            ExchangeGeneralException {
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

        // you should use this method only if the Public Contacts folder name
        //is diffrent then the default (Public Contacts)
        //connector.setPublicContactsFolderName("contacts2");


        ExchangeContactDTO contact = new ExchangeContactDTO();
        contact.setFirstName("guy1");
        contact.setLastName("jeno1");
        contact.setEmail("bushi@tech.com");
        _contactUniqueIdForURL = "" + System.currentTimeMillis();
        contact.setUniqueIdForUrl(_contactUniqueIdForURL);
        System.out.println("Adding contact: " + _contactUniqueIdForURL);
        connector.addPublicContact(contact);
        System.out.println(
                "look at the contact list to see that the contact is added.");
    }

    public static void updatePublicContactExample() throws
            ExchangeGeneralException {

        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

        // you should use this method only if the Public Contacts folder name
        //is diffrent then the default (Public Contacts)
        //connector.setPublicContactsFolderName("contacts2");


        ArrayList contacts = connector.getPublicContacts();

        for (int i = 0; i < contacts.size(); i++) {
            ExchangeContactDTO contact = (ExchangeContactDTO) contacts.get(i);

            String emailAddr = contact.getEmail();
            if (emailAddr.equals("elitest2@test.com")) {
                contact.setFirstName(contact.getFirstName() + " *changed*");
                connector.updatePublicContact(contact);
            }
        }
        System.out.println(
                "look at the contact list to see that the contact was updated.");

    }

    public static void getEventsORFilteredExample() throws
            ExchangeGeneralException {
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName, "GMT+2:00");

        SimpleDateFormat dateFormat = new SimpleDateFormat(
                "yyyy-MM-dd HH:mm:ss");
        Date startDate = null;
        Date endDate = null;
        try {
            startDate = dateFormat.parse("2007-02-01 08:00:00");
            endDate = dateFormat.parse("2007-02-01 21:00:00");
        } catch (ParseException ex) {
            ex.printStackTrace();
        }
        System.out.println("getting events from startDate: " + startDate +
                           " to endDate: " + endDate);
        try {

            // get all events that their subject contains the word "the" no case sensitive
            EventSearchCriteria eventSearchCriteria = new
                    OREventSearchCriteria(".*test.*", ".*test.*", ".*test.*",
                                          -1, -1);

            ArrayList events = connector.getEvents(startDate, endDate,
                    eventSearchCriteria);
            for (int i = 0; i < events.size(); i++) {
                System.out.println("event " + i + " subject: " +
                                   ((ExchangeEventDTO) events.get(i)).
                                   getSubject());
                System.out.println("event " + i + " location: " +
                                   ((ExchangeEventDTO) events.get(i)).
                                   getLocation());
                System.out.println("event " + i + " description: " +
                                   ((ExchangeEventDTO) events.get(i)).
                                   getDescription());

            }
        } catch (InvalidSearchCriteriaException e) {
            e.printStackTrace();
        }

    }

    public static void deleteFirstEventExample() throws
            ExchangeGeneralException {
        System.out.println("deleting the first event");
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

        connector.authenticate();

        SimpleDateFormat dateFormat = new SimpleDateFormat(
                "yyyy-MM-dd HH:mm:ss");
        Date startDate = null;
        Date endDate = null;
        try {
            startDate = dateFormat.parse("2007-01-24 21:00:00");
            endDate = dateFormat.parse("2007-02-14 21:00:00");

        } catch (ParseException ex) {
            ex.printStackTrace();
        }

        ArrayList events = connector.getEvents(startDate,
                                               endDate, 100);

        if (events.size() > 0) {
            System.out.println("Trying to Delete the first event" +
                               "event 0 subject: " +
                               ((ExchangeEventDTO) events.get(0)).getSubject()
                               + "event 0 subject: " +
                               ((ExchangeEventDTO) events.get(0)).
                               getUniqueIdForUrl());
            connector.deleteEvent(((ExchangeEventDTO) events.get(0)).
                                  getUniqueIdForUrl());
        }

    }

    public static void getEventsFromI18NEventFolderExample() throws
            ExchangeGeneralException {

        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;

        String mailboxName = "public";
        boolean useSSL = false;
        String prefix = "";
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

        connector.setCalendarFolderName("%D7%A4%D7%92%D7%99%D7%A9%D7%95%D7%AA");

        SimpleDateFormat dateFormat = new SimpleDateFormat(
                "yyyy-MM-dd HH:mm:ss");
        Date startDate = null;
        Date endDate = null;
        try {
            startDate = dateFormat.parse("2007-06-07 06:00:00");
            endDate = dateFormat.parse("2007-06-07 21:00:00");
        } catch (ParseException ex) {
            ex.printStackTrace();
        }
        System.out.println("getting events from startDate: " + startDate +
                           " to endDate: " + endDate);

        ArrayList events = connector.getEvents(startDate,
                                               endDate, 100);
        for (int i = 0; i < events.size(); i++) {
            System.out.println("event " + i + " subject: " +
                               ((ExchangeEventDTO) events.get(i)).getSubject());
            System.out.println("event " + i + " location: " +
                               ((ExchangeEventDTO) events.get(i)).getLocation());
            System.out.println("event " + i + " all day event: " +
                               ((ExchangeEventDTO) events.get(i)).
                               getIsAllDayEvent());
            System.out.println("event " + i + " Is Recurrent event: " +
                               ((ExchangeEventDTO) events.get(i)).
                               getIsRecurrent());

        }

    }

    public static void getEventsFromNestedEventFolderExample() throws
            ExchangeGeneralException {

        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;

        String mailboxName = "public";
        boolean useSSL = false;
        String prefix = "";
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                prefix, _useSSL, mailboxName);



        // working
        connector.setCalendarFolderName("public%20events/nested%20events");

        // not working
        //connector.setCalendarFolderName("public events");

        // not working
        //connector.setCalendarFolderName("/public events/nested events");

        // not working
        //connector.setCalendarFolderName("public events/nested events");


        SimpleDateFormat dateFormat = new SimpleDateFormat(
                "yyyy-MM-dd HH:mm:ss");
        Date startDate = null;
        Date endDate = null;
        try {
            startDate = dateFormat.parse("2007-06-07 06:00:00");
            endDate = dateFormat.parse("2007-06-07 21:00:00");
        } catch (ParseException ex) {
            ex.printStackTrace();
        }
        System.out.println("getting events from startDate: " + startDate +
                           " to endDate: " + endDate);

        ArrayList events = connector.getEvents(startDate,
                                               endDate, 100);
        for (int i = 0; i < events.size(); i++) {
            System.out.println("event " + i + " subject: " +
                               ((ExchangeEventDTO) events.get(i)).getSubject());
            System.out.println("event " + i + " location: " +
                               ((ExchangeEventDTO) events.get(i)).getLocation());
            System.out.println("event " + i + " all day event: " +
                               ((ExchangeEventDTO) events.get(i)).
                               getIsAllDayEvent());
            System.out.println("event " + i + " Is Recurrent event: " +
                               ((ExchangeEventDTO) events.get(i)).
                               getIsRecurrent());

        }

    }


    public static void getEventByIDExample() throws ExchangeGeneralException {
        System.out.println(
                "=========== getEventByIDExample start ===================");
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        // works
        //String eventID = "Team Leaders meeting-9";
        // works
        //String eventID = "/Team Leaders meeting-9";
        // works
        //String eventID = "test%20event%20eli%201";
//        String eventID = "{b7779b83-7b7f-494f-9dc4-c22b4558072c}";

//         String eventID = "{6b6baadd-ac23-4280-97cb-2a6d32971afd}";
//         String eventID = "{3F13CF32-2AC7-47D5-B175-3D640C39D874}";
         String eventID = "{217522FE-9CF1-4C4F-91AB-62E69A86BF61}";


        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

        System.out.println("getting event by id: " + eventID);

        ExchangeEventDTO event = connector.getEventById(eventID);
        System.out.println("event subject: " +
                           event.getSubject());
        System.out.println("event Organizer: " +
                           event.getOrganizer());
        System.out.println("event location: " +
                           event.getLocation());
        System.out.println("event all day event: " +
                           event.getIsAllDayEvent());
        System.out.println("event Is Recurrent event: " +
                           event.getIsRecurrent());
        System.out.println(
                "=========== getEventByIDExample end ====================");

    }

    public static void getEventAndUpdateIt() throws ExchangeGeneralException {
        System.out.println("======================= getEventAndUpdateIt start =================");
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        String subject2find = "test event eli 2";
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName, "GMT+00:00");

        SimpleDateFormat dateFormat = new SimpleDateFormat(
                "yyyy-MM-dd HH:mm:ss");
        Date startDate = null;
        Date endDate = null;
        try {
            startDate = dateFormat.parse("2007-06-06 06:00:00");
            endDate = dateFormat.parse("2007-06-06 21:00:00");
        } catch (ParseException ex) {
            ex.printStackTrace();
        }
        System.out.println("getting events from startDate: " + startDate +
                           " to endDate: " + endDate);

        ArrayList events = connector.getEvents(startDate,
                                               endDate, 5);
        for (int i = 0; i < events.size(); i++) {
           ExchangeEventDTO event = (ExchangeEventDTO) events.get(i);
           if(  event.getSubject().equals(subject2find) ) {
               String newDesc = event.getDescription() + " updated";
               System.out.println("event id: " + event.getUniqueIdForUrl() + " subject: " +
                       event.getSubject() + " found, updeting desctiption: " + event.getDescription() + " to new description: " + newDesc);
               event.setDescription(event.getDescription() + " updated");
               connector.updateEvent(event);

           }


        }
        System.out.println("======================= getEventAndUpdateIt end =================");

    }


    public static void getEmailsWithFBAExample() throws ExchangeGeneralException {
        System.out.println("============== getEmailsWithFBAExample() start ===========");
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;

        //String applicationUserAccountName = _fbaDomain + "/" + _applicationUserAccountName;
        boolean useSSL = true;
        String domain = "domain1.com";

        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, useSSL, _mailboxName);
        connector.setDomain(domain);
        connector.setUseFba(true);
        //connector.setFbaPath("/exchweb/bin/auth/owalogon.asp");
        //connector.setGetOnlyUnreadEmails(false);


        int maxEmailsReturned = 10;
        ArrayList emailsArrayList = connector.getEmails(
                null,
                null,
                null,
                maxEmailsReturned);

        System.out.println("emailsArrayList.size() : " + emailsArrayList.size());
        if (emailsArrayList.size() > 0) {
            for (int i = 0; i <= emailsArrayList.size() - 1; i++) {
                System.out.println("email " + i + " information: ");
                ExchangeEmailDTO email = (ExchangeEmailDTO) emailsArrayList.get(i);
                System.out.println("email.getUniqueIdForUrl(): " + email.getUniqueIdForUrl());
                System.out.println("email.getDateReceived(): " + email.getDateReceived());
                System.out.println("email.getSubject(): " + email.getSubject());
                System.out.println("email.getFromEmailName(): " + email.getFromEmailName());
                if ((email.getToEmailAddresses() != null) && (email.getToEmailAddresses().length > 0) )
                    System.out.println("email.getToEmailNames()[0]: " + email.getToEmailNames()[0]);
                if (i==1) {
                    System.out.println("======================================================");
                    System.out.println("email.getBody(): " + email.getBody());
                    System.out.println("======================================================");
                }

//                if (email.getMimeMultipart() != null) {
//                    System.out.println("----------the email is MimeMultipart, you can use email.getMimeMultipart() to get the javamail Object");
//                    System.out.println("---------- Or email.getEmailStr() to get the full multipart mime String (The String may be very long).");

                    // uncomment to print the full mime
                    //System.out.println("---------- using email.getEmailStr(): ");
                    //System.out.println(email.getEmailStr());

//                }
                else if (email.getHtmlBody() != null) {
                    System.out.println("----------the email is mimeOLE, use getHtmlBody() to get the body (as html)");
                }
                else if (email.getBody() != null) {
                    System.out.println("----------Text Body, use email.getBody() to get the body");
                }
            }

        }
        System.out.println("============== getEmailsWithFBAExample() end ============");
    }


    public static void deleteEmailUsingIdExample() throws
            ExchangeGeneralException {
        System.out.println(
                "============== deleteEmailExample() start ===========");
        System.out.println("Going to delete an email with subject jectest make sure you have one in your inbox");
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;

        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);
        //connector.setUseFba(true);
        //connector.setDomain(_domain);
        connector.setDeletedFolderName("Deleted%20Items");
        String url = null;
        int maxEmailsReturned = 10;
        ArrayList emails = connector.getEmails(
                null,
                null,
                null,
                maxEmailsReturned);

        ExchangeEmailDTO emailDTO = null;
        for (int i = 0; i < emails.size(); i++) {
            emailDTO = (ExchangeEmailDTO) emails.get(i);
            if (emailDTO.getSubject().equals("jectest"))
                break;
        }

        if (emailDTO != null) {
            if (! (emailDTO.getUniqueIdForUrl().indexOf("jectest") > 0)  )
                System.out.println("didnt find email with subject jectest");
            connector.deleteEmail(emailDTO.getUniqueIdForUrl());
        }
        System.out.println(
                "============== deleteEmailExample() end ============");
    }

    public static void searchAndDeleteEmailExample() throws
             ExchangeGeneralException {
         System.out.println(
                 "============== deleteEmailExample() start ===========");
         System.out.println("Going to delete an email with subject jectest make sure you have one in your inbox");
         ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
         ExchangeConnectorInterface connector = null;

         connector = factory.createExchangeConnector(_exchangeHost,
                 _applicationUserAccountName,
                 _applicationUserPassword,
                 _prefix, _useSSL, _mailboxName);
         //connector.setUseFba(true);
         //connector.setDomain(_domain);
         connector.setDeletedFolderName("Deleted%20Items");
         String url = null;
         int maxEmailsReturned = 10;
         ArrayList emails = connector.getEmails(
                 null,
                 null,
                 null,
                 maxEmailsReturned);

         ExchangeEmailDTO emailDTO = null;
         for (int i = 0; i < emails.size(); i++) {
             emailDTO = (ExchangeEmailDTO) emails.get(i);
             if (emailDTO.getSubject().equals("jectest"))
                 break;
         }

         if (emailDTO != null) {
             if (! (emailDTO.getSubject().indexOf("jectest") > 0)  )
                 System.out.println("didnt find email with subject jectest");
             connector.deleteEmail(emailDTO.getUniqueIdForUrl());
         }
         System.out.println(
                 "============== deleteEmailExample() end ============");
    }

    public static void deleteEmailFromDraftsFolderExample() throws
            ExchangeGeneralException {
        System.out.println(
                "============== deleteEmailExample() start ===========");
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;

        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);
        connector.setEmailFolderName("drafts");
        connector.setDeletedFolderName("Deleted%20Items");
        connector.deleteEmail(_emailUniqueIdForUrl);
        System.out.println(
                "============== deleteEmailExample() end ============");
    }



public static void getUserAvalabilityExample() throws ExchangeGeneralException {
    System.out.println("======================= getUserAvalabilityExample start =================");
    String _email = "ehasson@domain.com";

    ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
    ExchangeConnectorInterface connector = null;
    connector = factory.createExchangeConnector(_exchangeHost,
            _applicationUserAccountName,
            _applicationUserPassword,
            _prefix, _useSSL, _mailboxName, "GMT+00:00");

    // Get email address from user
//    System.out.print(
//    "Please insert email address (in most cases its the same as the user name @ your host/domain): ");
//    BufferedReader in = new BufferedReader(new InputStreamReader(System.
//            in));
//    String str = null;
//        try {
//            str = in.readLine();
//        } catch (IOException ex1) {
//            ex1.printStackTrace();
//        }
//        if ((str != null) && (!str.equals("")))
//            _email = str;
        System.out.println("");
        System.out.println("Email Address:" + _email);

        SimpleDateFormat dateFormat = new SimpleDateFormat(
            "yyyy-MM-dd HH:mm:ss");
    Date startDate = null;
    Date endDate = null;
    try {
        startDate = dateFormat.parse("2007-07-22 00:00:00");
        endDate = dateFormat.parse("2007-07-22 21:00:00");
    } catch (ParseException ex) {
        ex.printStackTrace();
    }
    System.out.println("getting user availability from startDate: " + startDate +
                       " to endDate: " + endDate);


    ExchangeEventAttendeeDTO exchangeEventAttendeeTDO = new ExchangeEventAttendeeDTO();
    exchangeEventAttendeeTDO.setEmailAddr(_email);
    UserAvailabilityData userAvailabilityData = connector.getUserAvailabilityData(startDate, endDate, 30, exchangeEventAttendeeTDO);
    System.out.println("userAvailabilityData.getSchedulingDataStr(): " + userAvailabilityData.getSchedulingDataStr());
    System.out.println("======================= getUserAvalabilityExample end =================");
}


       public static void sendMeetingRequestExample() throws ExchangeGeneralException {

        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        String emailfrom = "test2@domain1.com";
        String emailTo = "test1@domain1.com";

        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName, "GMT+02:00");

                ExchangeEventDTO exchangeEventDTO = new ExchangeEventDTO();
                exchangeEventDTO.setStartDate(new Date());
                exchangeEventDTO.setLocation("location 21");
                exchangeEventDTO.setEndDate(new Date());
                exchangeEventDTO.setSubject("Meet Me");
                exchangeEventDTO.setDescription("This is a test meeting");

                ExchangeEventAttendeeDTO from = new ExchangeEventAttendeeDTO();
                from.setEmailAddr(emailfrom);
                exchangeEventDTO.setFrom(from);

                ExchangeEventAttendeeDTO to1 = new ExchangeEventAttendeeDTO();
                to1.setEmailAddr(emailTo);
                exchangeEventDTO.addTo(to1);


                ExchangeEventAttendeeDTO to2 = new ExchangeEventAttendeeDTO();
                to2.setEmailAddr("test3@domain1.com");
                to2.setType(ExchangeEventAttendeeDTO.ATTENDEE_TYPE_OPTIONAL);
                exchangeEventDTO.addTo(to2);



                connector.sendMeetingRequest(exchangeEventDTO);
                System.out.println("check out your inbox you should have received an invitation for a meeting");
        }

        public static void createConnectorWithExplicitLicenseFileLocationExample() throws
                ExchangeGeneralException {
            System.out.println("========== createConnectorWithExplicitLicenseFileLocationExample start =================");

            ExchangeConnectorFactory factory = new ExchangeConnectorFactory(
                    "C:/projects/JEC/jec/lib");
            ExchangeConnectorInterface connector = null;
            connector = factory.createExchangeConnector(_exchangeHost,
                    _applicationUserAccountName,
                    _applicationUserPassword,
                    _prefix, _useSSL, _mailboxName, "GMT+00:00");
            System.out.println("connector: " + connector +
                               " created using explicit license file location.");
            System.out.println("========== createConnectorWithExplicitLicenseFileLocationExample end =================");

        }




        public static void addContactSubFolderExample() throws ExchangeGeneralException {

            ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
            ExchangeConnectorInterface connector = null;
            connector = factory.createExchangeConnector(_exchangeHost,
                    _applicationUserAccountName,
                    _applicationUserPassword,
                    _prefix, _useSSL, _mailboxName);
            connector.setContactsFolderName("Contacts/private%20contacts");

            ExchangeContactDTO contact = new ExchangeContactDTO();
            contact.setFirstName("guy1");
            contact.setLastName("jeno1");
            contact.setMiddleName("puni");
            contact.setEmail("bushi@tech.com");
            _contactUniqueIdForURL = "" + System.currentTimeMillis();
            contact.setUniqueIdForUrl(_contactUniqueIdForURL);
            System.out.println("Adding contact: " + _contactUniqueIdForURL);
            connector.addContact(contact);
            System.out.println(
                    "look at the contact list to see that the contact is added.");
        }



        public static void getContactsSubFloderExample() throws
                ExchangeGeneralException {
            ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
            ExchangeConnectorInterface connector = null;
            connector = factory.createExchangeConnector(_exchangeHost,
                    _applicationUserAccountName,
                    _applicationUserPassword,
                    _prefix, _useSSL, _mailboxName);
            connector.setContactsFolderName("Contacts/private%20contacts");

            ArrayList contacts = connector.getContacts();

            for (int i = 0; i < contacts.size(); i++) {
                ExchangeContactDTO contact = (ExchangeContactDTO) contacts.get(i);
                System.out.println("contact.getUniqueIdForUrl: " + contact.getUniqueIdForUrl());
                System.out.println("contact.getFirstName(): " +
                                   contact.getFirstName());
                System.out.println("contact.getMiddleName(): " + contact.getMiddleName());
                System.out.println("contact.getLastName(): " + contact.getLastName());

                System.out.println("");

            }
        }

        public static void createEmailInDraftsFolderExample() throws
                ExchangeGeneralException {
            System.out.println(
                    "============== createEmailInFolderExample() start ===========");
            ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
            ExchangeConnectorInterface connector = null;

            connector = factory.createExchangeConnector(_exchangeHost,
                    _applicationUserAccountName,
                    _applicationUserPassword,
                    _prefix, _useSSL, _mailboxName);

            connector.setEmailFolderName("drafts");
            ExchangeEmailDTO email = new ExchangeEmailDTO();
            _emailUniqueIdForUrl = "" + System.currentTimeMillis();
            email.setUniqueIdForUrl(_emailUniqueIdForUrl);
            email.setSubject("test email for drafts");
            email.setBody("test body");
            email.setFrom("test2@domain1.com");
            email.setTo(" user1@domain.com, user1@domain.com");
            email.setCc("test1@domain1.com");
            email.setBcc("tuti@domain.com");
            connector.createOrUpdateEmail(email);
            System.out.println("email: " + email.getUniqueIdForUrl() + " create or updated, check the folder: " +
                               connector.getEmailFolderName());

            System.out.println(
                    "============== createEmailInFolderExample() end ============");
        }


        public static void  sendEmailThatExistsInExchangeExample() throws
                ExchangeGeneralException {
            System.out.println(
                    "============== sendEmailThatExistsInExchangeExample() start ===========");
            ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
            ExchangeConnectorInterface connector = null;

            connector = factory.createExchangeConnector(_exchangeHost,
                    _applicationUserAccountName,
                    _applicationUserPassword,
                    _prefix, _useSSL, _mailboxName);

            connector.setEmailFolderName("drafts");
            connector.sentEmail("1187875469932");
            System.out.println(
                    "============== sendEmailThatExistsInExchangeExample() end ===========");
        }

        public static void sendEmailExample() throws
                ExchangeGeneralException {
            System.out.println(
                    "============== sendEmailExample() start ===========");

            // this need to be corrected to a valid email address.
            String emailfrom = "test1@domain1.com";

            ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
            ExchangeConnectorInterface connector = null;

            connector = factory.createExchangeConnector(_exchangeHost,
                    _applicationUserAccountName,
                    _applicationUserPassword,
                    _prefix, _useSSL, _mailboxName);

            // this is needed in case exchange is not an English one.
            connector.setDraftsFolderName("drafts");

            ExchangeEmailDTO email = new ExchangeEmailDTO();
            String emailUniqueId = "" + System.currentTimeMillis();
            email.setUniqueIdForUrl(emailUniqueId);
            email.setSubject("test email for send");
            email.setBody("test body for send");

            // for html text comment the upper line (regular text body, and uncomment the below line
            //email.setHtmlBody("<P>Hamlet's famous speech begins:<BLOCKQUOTE><I>To be, or not to be?<BR>That is the question</I></BLOCKQUOTE>");
            email.setFrom(emailfrom);
            email.setTo("test2@domain1.com");
            email.setCc("test3@domain1.com");
            //email.setBcc("test4@domain1.com");
            connector.sendEmail(email);
            System.out.println("============== sendEmailExample() end ============");
        }

        public static void deleteTaskExample() throws ExchangeGeneralException {
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

        try {
            System.out.println("Deleting task: " + _taskUniqueIdForURL);
            connector.deleteTask(_taskUniqueIdForURL);
        }

        catch (ExchangeGeneralException ex) {
            ex.printStackTrace();
        }
    }


    public static void addEventWithAttendeesExample() throws ExchangeGeneralException {
        System.out.println("============= addEventWithMeetingReqsExample start. ==========");
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;
        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName, "GMT+02:00" );

        String emailfrom = "test2@domain1.com";
        String emailTo1 = "test1@domain1.com";
        String emailTo2 = "test3@domain1.com";

        // in case you dont want to send meeting requests, but you want to add the attendees to
        // the meeting, uncomment this line.
        // in case send meeting is true, you'll need to install the optional package
        // download from: http://jec-users.googlegroups.com/web/optional1.0.zip?gda=eVYGfkAAAAA_NSrvJ0P5DI-9bvJkcZCa5Ggbk6bEOimn1NyX_8i6xWG1qiJ7UbTIup-M2XPURDTahN4g7xphsKA8V9oYIn&hl=en
        connector.setSendMeetingReqs(true);

        // this is needed to send a correct meeting request, for the format of this String look at the connector api docs
        connector.setFullTimezonStr4MeetingReq("(GMT+02.00) Israel/Jerusalem Standard Time");

        SimpleDateFormat dateFormat = new SimpleDateFormat(
                "yyyy-MM-dd HH:mm:ss");
        Date startDate = null;
        Date endDate = null;
        try {
            startDate = dateFormat.parse("2007-10-09 18:00:00");
            endDate = dateFormat.parse("2007-10-09 19:00:00");
        } catch (ParseException ex) {
            ex.printStackTrace();
        }

        ExchangeEventDTO event = new ExchangeEventDTO();
        ExchangeEventAttendeeDTO from = new ExchangeEventAttendeeDTO();
        from.setEmailAddr(emailfrom);
        event.setFrom(from);

//        ExchangeEventAttendeeDTO to1 = new ExchangeEventAttendeeDTO();
//        to1.setEmailAddr(_email);
//        event.addTo(to1);

        ExchangeEventAttendeeDTO to2 = new ExchangeEventAttendeeDTO();
        to2.setType(ExchangeEventAttendeeDTO.ATTENDEE_TYPE_REQUIRED);
        to2.setEmailAddr(emailTo1);
        event.addTo(to2);

        ExchangeEventAttendeeDTO to3 = new ExchangeEventAttendeeDTO();
        to3.setType(ExchangeEventAttendeeDTO.ATTENDEE_TYPE_OPTIONAL);
        to3.setEmailAddr(emailTo2);
        event.addTo(to3);



        event.setSubject("eli test event1");
        event.setLocation("test location");
        event.setDescription("my test event");
        event.setStartDate(startDate);
        event.setEndDate(endDate);
        event.setImportance(2);
        event.setBusyStatus(ExchangeEventDTO._calendarBusyStatus_BUSY);
        //event.setIsAllDayEvent(true);

        try {
            connector.addEvent(event);
        } catch (java.lang.NoClassDefFoundError ex1) {
            ex1.printStackTrace();
            System.out.println("you probelby missing the optional package,");
            System.out.println("download from the JEC User group, files, optional.zip");
        }
        System.out.println("look at: " + startDate +
                           " events to see that the event was added.");


    }

    public static void acceptMeetingExample() throws ExchangeGeneralException {
        System.out.println("============== acceptMeetingExample() start ===========");
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;

        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                _prefix, _useSSL, _mailboxName);

        SimpleDateFormat dateFormat = new SimpleDateFormat(
                "yyyy-MM-dd HH:mm:ss");
        Date sinceDate = null;
        try {
            sinceDate = dateFormat.parse("2007-01-25 06:00:00");
        } catch (ParseException ex) {
            ex.printStackTrace();
        }

        int maxEmailsReturned = 100;

        // we need to get full email Str in-order to parse the meeting request part
        connector.setGetFullEmailStr(true);

        // open the comment if you want to accept the meeting, but not to send
        // accept email.
        //connector.setSendMeetingAcceptEmail(false);

        ArrayList emailsArrayList = connector.getEmails(
                sinceDate,
                null,
                null,
                maxEmailsReturned);
       System.out.println("emailsArrayList.size() : " + emailsArrayList.size());
       for (int i = 0; i <  emailsArrayList.size(); i++) {
           ExchangeEmailDTO email = (ExchangeEmailDTO) emailsArrayList.get(i);
           System.out.println("subject: " + email.getSubject());
           if (email.isMeetingRequest()) {
               System.out.println("found meeting request email accepting ...");
               System.out.println(email.getEmailStr());
               System.out.println("getMeetingStartTimeStr: " + email.getMeetingStartTimeStr());
               System.out.println("getMeetingDescription: " + email.getMeetingDescription());
               System.out.println("getMeetingReqLocation: " + email.getMeetingReqLocation());
               connector.accept(email);
           }

       }


    }

    public static void getEmailsFromPublicFolderExample() throws
            ExchangeGeneralException {
        System.out.println(
                "============== getEmailsExample() start ===========");
        ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
        ExchangeConnectorInterface connector = null;

        String mailboxName = "public";
        String prefix = "";

        connector = factory.createExchangeConnector(_exchangeHost,
                _applicationUserAccountName,
                _applicationUserPassword,
                prefix, _useSSL, mailboxName);

        connector.setEmailFolderName("public%20email");

        SimpleDateFormat dateFormat = new SimpleDateFormat(
                "yyyy-MM-dd HH:mm:ss");
        Date sinceDate = null;
        try {
            sinceDate = dateFormat.parse("2007-10-03 17:00:00");
        } catch (ParseException ex) {
            ex.printStackTrace();
        }
        HashSet fromEmailAddressFilter = null;

        HashSet toEmailAddressFilter = null;
        int maxEmailsReturned = 10;
        ArrayList emailsArrayList = connector.getEmails(
                sinceDate,
                fromEmailAddressFilter,
                toEmailAddressFilter,
                maxEmailsReturned);
        System.out.println("emailsArrayList.size() : " + emailsArrayList.size());
        for (int i = 0; i < emailsArrayList.size(); i++) {
            ExchangeEmailDTO email = (ExchangeEmailDTO) emailsArrayList.get(i);
            System.out.println("email1.getUniqueIdForUrl(): " +
                               email.getUniqueIdForUrl());
            System.out.println("email1.getSubject(): " +
                               email.getSubject());
//            System.out.println("email1.getBody(): " +
//                               email.getBody());
            System.out.println("email1.getDateReceived(): " +
                               email.getDateReceived());
            System.out.println("email1.getTo(): " +
                               email.getTo());
            System.out.println("email1.getFrom(): " +
                               email.getFrom());
            System.out.println("email1.isRead: " +
                               email.isRead());
            System.out.println("email1.getCc: " +
                               email.getCc());
            System.out.println("email1.getBcc: " +
                               email.getBcc());
            System.out.println("");

        }
        System.out.println("============== getEmailsExample() end ============");
    }

    public static void getFoldersExample() throws ExchangeGeneralException {
    	ExchangeConnectorFactory factory = new ExchangeConnectorFactory();
    	ExchangeConnectorInterface connector = null;
    	connector = factory.createExchangeConnector(_exchangeHost,
    			_applicationUserAccountName,
    			_applicationUserPassword,
    			_prefix, _useSSL, _mailboxName);

//  	connector.setUseFba(true);
//  	connector.setDomain(_domain);

    	ArrayList folders = connector.getRootFolders();

    	String folderUrl = null;
    	String folderName = null;
    	String subFolderUrl = null;
    	for (int i = 0; i < folders.size(); i++) {
    		folderUrl = ((FolderDTO)folders.get(i)).getUrl();
    		folderName = ((FolderDTO)folders.get(i)).getName();
    		System.out.println("folder Url: " + folderUrl   );
    		System.out.println("folder name: " + folderName   );
    		ArrayList subFolders =  null;
    		if (folderName.equals("emails_test")) {
    			subFolders = connector.getFolders(folderUrl);
    			for (int j = 0; j < subFolders.size(); j++) {
    				subFolderUrl = ((FolderDTO)subFolders.get(j)).getUrl();
    				System.out.println("subfolder Url: " + subFolderUrl   );
    			}
    		}
    	}
    }


}
